@@ -19,21 +19,33 @@
 
 #include <cstring>
 #include <iostream>
-
-#include <osmscout/Database.h>
-#include <osmscout/DebugDatabase.h>
-
-#include <osmscout/routing/RouteNode.h>
-#include <osmscout/TypeFeatures.h>
-
-#include <osmscout/routing/RouteNodeDataFile.h>
-#include <osmscout/routing/RoutingService.h>
-
 #include <list>
 #include <map>
 #include <string>
 #include <vector>
 
+#include <osmscout/db/Database.h>
+#include <osmscout/db/DebugDatabase.h>
+
+#include <osmscout/routing/RouteNode.h>
+
+#include <osmscout/feature/AccessFeature.h>
+#include <osmscout/feature/AccessRestrictedFeature.h>
+#include <osmscout/feature/AddressFeature.h>
+#include <osmscout/feature/AdminLevelFeature.h>
+#include <osmscout/feature/IsInFeature.h>
+#include <osmscout/feature/LanesFeature.h>
+#include <osmscout/feature/LayerFeature.h>
+#include <osmscout/feature/LocationFeature.h>
+#include <osmscout/feature/NameFeature.h>
+#include <osmscout/feature/NameAltFeature.h>
+#include <osmscout/feature/RefFeature.h>
+#include <osmscout/feature/SidewayFeature.h>
+#include <osmscout/feature/WidthFeature.h>
+
+#include <osmscout/routing/RouteNodeDataFile.h>
+#include <osmscout/routing/RoutingService.h>
+
 /*
  * Example:
  *   src/DumpData ../TravelJinni/ -n 25293125 -w 4290108 -w 26688152 -r 531985
@@ -526,12 +538,22 @@ static void DumpLanesFeatureValue(const osmscout::LanesFeatureValue& lanesValue,
 
   if (!lanesValue.GetTurnForward().empty()) {
     DumpIndent(indent+2);
-    std::cout << "TurnForward: " << lanesValue.GetTurnForward() << std::endl;
+    std::cout << "TurnForward: ";
+    for (auto turn: lanesValue.GetTurnForward()) {
+      std::cout << LaneTurnString(turn);
+      std::cout << " ";
+    }
+    std::cout << std::endl;
   }
 
   if (!lanesValue.GetTurnBackward().empty()) {
     DumpIndent(indent+2);
-    std::cout << "TurnBackward: " << lanesValue.GetTurnBackward() << std::endl;
+    std::cout << "TurnBackward: ";
+    for (auto turn: lanesValue.GetTurnForward()) {
+      std::cout << LaneTurnString(turn);
+      std::cout << " ";
+    }
+    std::cout << std::endl;
   }
 
   if (!lanesValue.GetDestinationForward().empty()) {
@@ -877,17 +899,17 @@ int main(int argc, char* argv[])
       1000);
 
   if (!database.Open(map)) {
-    std::cerr << "Cannot open database" << std::endl;
+    std::cerr << "Cannot open db" << std::endl;
   }
 
   if (!debugDatabase.Open(map)) {
-    std::cerr << "Cannot open debug database" << std::endl;
+    std::cerr << "Cannot open debug db" << std::endl;
   }
 
   if (!routeNodeDataFile.Open(database.GetTypeConfig(),
                               map,
                               true)) {
-    std::cerr << "Cannot open routing database" << std::endl;
+    std::cerr << "Cannot open routing db" << std::endl;
   }
 
   // OSM ids
