@@ -19,7 +19,7 @@
 
 #include <osmscoutimport/PreprocessPBF.h>
 
-#include <osmscout/private/Config.h>
+#include <osmscoutimport/private/Config.h>
 #include <osmscoutimport/ImportFeatures.h>
 
 #include <cstdio>
@@ -39,7 +39,8 @@
   #include <zlib.h>
 #endif
 
-#include <osmscout/util/File.h>
+#include <osmscout/io/File.h>
+
 #include <osmscout/util/String.h>
 
 #define MAX_BLOCK_HEADER_SIZE (64*1024)
