@@ -23,14 +23,15 @@
 
 #include <osmscout/system/Assert.h>
 
-#include <osmscout/util/Geometry.h>
-#include <osmscout/util/Logger.h>
-#include <osmscout/util/StopClock.h>
+#include <osmscout/feature/NameFeature.h>
 
 #include <osmscout/routing/RoutingService.h>
 #include <osmscout/routing/SimpleRoutingService.h>
 #include <osmscout/routing/RoutingProfile.h>
 
+#include <osmscout/util/Geometry.h>
+#include <osmscout/log/Logger.h>
+#include <osmscout/util/StopClock.h>
 
 //#define DEBUG_ROUTING
 
@@ -41,7 +42,7 @@ namespace osmscout {
    * Create a new instance of the routing service.
    *
    * @param database
-   *    A valid reference to a database instance
+   *    A valid reference to a db instance
    * @param parameter
    *    An instance to the parameter object holding further paramterization
    */
@@ -81,7 +82,7 @@ namespace osmscout {
   }
 
   bool SimpleRoutingService::CanUse(const RoutingProfile& profile,
-                                    const DatabaseId /*database*/,
+                                    const DatabaseId /*db*/,
                                     const RouteNode& routeNode,
                                     size_t pathIndex)
   {
@@ -89,21 +90,21 @@ namespace osmscout {
   }
 
   bool SimpleRoutingService::CanUseForward(const RoutingProfile& profile,
-                                           const DatabaseId& /*database*/,
+                                           const DatabaseId& /*db*/,
                                            const WayRef& way)
   {
     return profile.CanUseForward(*way);
   }
 
   bool SimpleRoutingService::CanUseBackward(const RoutingProfile& profile,
-                                            const DatabaseId& /*database*/,
+                                            const DatabaseId& /*db*/,
                                             const WayRef& way)
   {
     return profile.CanUseBackward(*way);
   }
 
   double SimpleRoutingService::GetCosts(const RoutingProfile& profile,
-                                        const DatabaseId /*database*/,
+                                        const DatabaseId /*db*/,
                                         const RouteNode& routeNode,
                                         size_t inPathIndex,
                                         size_t outPathIndex)
@@ -112,29 +113,34 @@ namespace osmscout {
   }
 
   double SimpleRoutingService::GetCosts(const RoutingProfile& profile,
-                                        const DatabaseId /*database*/,
+                                        const DatabaseId /*db*/,
                                         const WayRef &way,
                                         const Distance &wayLength)
   {
     return profile.GetCosts(*way,wayLength);
   }
 
+  double SimpleRoutingService::GetUTurnCost(const RoutingProfile& profile, const DatabaseId /*databaseId*/)
+  {
+    return profile.GetUTurnCost();
+  }
+
   double SimpleRoutingService::GetEstimateCosts(const RoutingProfile& profile,
-                                                const DatabaseId /*database*/,
+                                                const DatabaseId /*db*/,
                                                 const Distance &targetDistance)
   {
     return profile.GetCosts(targetDistance);
   }
 
   double SimpleRoutingService::GetCostLimit(const RoutingProfile& profile,
-                                            const DatabaseId /*database*/,
+                                            const DatabaseId /*db*/,
                                             const Distance &targetDistance)
   {
     return profile.GetCosts(profile.GetCostLimitDistance()) + profile.GetCosts(targetDistance)*profile.GetCostLimitFactor();
   }
 
   std::string SimpleRoutingService::GetCostString(const RoutingProfile& profile,
-                                                  DatabaseId /*database*/,
+                                                  DatabaseId /*db*/,
                                                   double cost) const
   {
     return profile.GetCostString(cost);
@@ -308,7 +314,7 @@ namespace osmscout {
   }
 
   std::vector<DBId> SimpleRoutingService::GetNodeTwins(const RoutingProfile& /*state*/,
-                                                       const DatabaseId /*database*/,
+                                                       const DatabaseId /*db*/,
                                                        const Id /*id*/)
   {
     std::vector<DBId> result;
@@ -359,10 +365,10 @@ namespace osmscout {
   }
 
   /**
-   * Returns the type configuration of the underlying database instance
+   * Returns the type configuration of the underlying db instance
    *
    * @return
-   *    A valid type configuration or null if the database is not valid
+   *    A valid type configuration or null if the db is not valid
    */
   TypeConfigRef SimpleRoutingService::GetTypeConfig() const
   {
@@ -416,14 +422,16 @@ namespace osmscout {
 
       partialResult=CalculateRoute(profile,
                                    RoutePosition(fromObject,
-                                                 fromNodeIndex,/*database*/
+                                                 fromNodeIndex,/*db*/
                                                  0),
                                    RoutePosition(toObject,
-                                                 toNodeIndex,/*database*/
+                                                 toNodeIndex,/*db*/
                                                  0),
+                                   std::nullopt,
                                    parameter);
       if (!partialResult.Success()) {
         result.GetRoute().Clear();
+        result.ClearSectionLengths();
 
         return result;
       }
@@ -435,6 +443,7 @@ namespace osmscout {
       }
 
       result.GetRoute().Append(partialResult.GetRoute());
+      result.AppendSectionLength(partialResult.GetRoute().Entries().size());
     }
 
     return result;
@@ -495,7 +504,7 @@ namespace osmscout {
         }
       }
 
-      position=RoutePositionResult(RoutePosition(way->GetObjectFileRef(), wayCenter,/*database*/0), Distance::Zero());
+      position=RoutePositionResult(RoutePosition(way->GetObjectFileRef(), wayCenter,/*db*/0), Distance::Zero());
     }
     // TODO: support areas in router
 
@@ -599,7 +608,7 @@ namespace osmscout {
         if (distance<minDistance) {
           minDistance=distance;
 
-          position=RoutePositionResult(RoutePosition(area->GetObjectFileRef(),i,/*database*/0),
+          position=RoutePositionResult(RoutePosition(area->GetObjectFileRef(),i,/*db*/0),
                                        GetEllipsoidalDistance(coord, area->rings[0].nodes[i].GetCoord()));
         }
       }
@@ -622,10 +631,10 @@ namespace osmscout {
         if (distance<minDistance) {
           minDistance=distance;
           if(r<0.5){
-            position=RoutePositionResult(RoutePosition(way->GetObjectFileRef(),i,/*database*/0),
+            position=RoutePositionResult(RoutePosition(way->GetObjectFileRef(),i,/*db*/0),
                                          GetEllipsoidalDistance(coord, GeoCoord(intersectLat, intersectLon)));
           } else {
-            position=RoutePositionResult(RoutePosition(way->GetObjectFileRef(),i+1,/*database*/0),
+            position=RoutePositionResult(RoutePosition(way->GetObjectFileRef(),i+1,/*db*/0),
                                          GetEllipsoidalDistance(coord, GeoCoord(intersectLat, intersectLon)));
           }
         }
